@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.31";
+our $VERSION = "0.3101";
 
 =encoding utf-8
 
@@ -16,7 +16,7 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.31
+Version 0.3101
 
 =head1 DESCRIPTION
 
@@ -57,6 +57,18 @@ If you want to translate entire text, use B<--match-all> option.  This
 is a short-cut to specify the pattern C<(?s).+> which matches entire
 text.
 
+Conflict marker format data can be viewed in side-by-side style by
+C<sdif> command with C<-V> option.  Since it makes no sense to compare
+on a per-string basis, the C<--no-cdif> option is recommended.  If you
+do not need to color the text, specify C<--no-color> or C<--cm
+'TEXT*='>.
+
+    sdif -V --cm '*TEXT=' --no-cdif data_shishin.deepl-EN-US.cm
+
+=for html <p>
+<img width="750" src="https://raw.githubusercontent.com/kaz-utashiro/App-Greple-xlate/main/images/sdif-cm-view.png">
+</p>
+
 =head1 OPTIONS
 
 =over 7
